==> scanbot_sdk-2.0.1.tar.gz: lib/barcode_parsers/de_medical_plan.dart <==
import 'dart:core';

import 'package:json_annotation/json_annotation.dart';
import 'package:scanbot_sdk/barcode_parsers/barcode_scanner.dart';

part 'de_medical_plan.g.dart';

@JsonSerializable(
    nullable: true,
    createFactory: true,
    includeIfNull: false,
    explicitToJson: true)

/// German medical plan barcode parsed document
class DEMedicalPlanDocument extends BarcodeFormattedResult {
  static const String DOCUMENT_FORMAT = "DEMedicalPlan";

  /** Document ID */
  String GUID;

  /** Current page index */
  int currentPage = 0;

  /** Total number of pages */
  int totalNumberOfPages = 0;

  /** Document version */
  String documentVersionNumber;

  /** Patch version */
  String patchVersionNumber;

  /** Language and country code */
  String languageCountryCode;

  /** Patient information */
  DEMedicalPlanPatientInformation patient;

  /** Doctor information */
  DEMedicalPlanDoctorInformation doctor;

  /** Treatment subheadings */
  List<DEMedicalPlanStandardSubheading> subheadings;

  DEMedicalPlanDocument({this.GUID, this.currentPage, this.totalNumberOfPages,
    this.documentVersionNumber, this.patchVersionNumber,
    this.languageCountryCode, this.patient, this.doctor, this.subheadings})
      : super(DOCUMENT_FORMAT);


  factory DEMedicalPlanDocument.fromJson(Map<String, dynamic> json) =>
      _$DEMedicalPlanDocumentFromJson(json);

  Map<String, dynamic> toJson() => _$DEMedicalPlanDocumentToJson(this);
}

@JsonSerializable(
    nullable: true,
    createFactory: true,
    includeIfNull: false,
    explicitToJson: true)
class DEMedicalPlanPatientInformation {

  /** Patient fields */
  List<DEMedicalPlanPatientField> fields;

  DEMedicalPlanPatientInformation(this.fields);

  factory DEMedicalPlanPatientInformation.fromJson(Map<String, dynamic> json) =>
      _$DEMedicalPlanPatientInformationFromJson(json);

  Map<String, dynamic> toJson() =>
      _$DEMedicalPlanPatientInformationToJson(this);
}

/// German medical plan patient information field
@JsonSerializable(
    nullable: true,
    createFactory: true,
    includeIfNull: false,
    explicitToJson: true)
class DEMedicalPlanPatientField {

  /// Value
  String value;

  /// Type
  DEMedicalPlanPatientFieldType type;

  DEMedicalPlanPatientField(this.value, this.type);

  factory DEMedicalPlanPatientField.fromJson(Map<String, dynamic> json) =>
      _$DEMedicalPlanPatientFieldFromJson(json);

  Map<String, dynamic> toJson() => _$DEMedicalPlanPatientFieldToJson(this);
}

/// German medical plan document patient information description field type
enum DEMedicalPlanPatientFieldType {
  FirstName, // MP.P.g
  LastName, // MP.P.f
  Title, // MP.P.t
  PreName, // MP.P.v
  Suffix, // MP.P.z
  PatientID, // MP.P.egk
  BirthDate, // MP.P.b
  Gender, // MP.P.s
  Weight, // MP.O.w
  Height, // MP.O.h
  CreatinineValue, // MP.O.c
  AllergiesAndIntolerances, // MP.O.ai
  BreastFeeding, // MP.O.b
  Pregnant, // MP.O.p
  PatientFreeText // MP.O.x
}

/// German medical plan doctor information
@JsonSerializable(
    nullable: true,
    createFactory: true,
    includeIfNull: false,
    explicitToJson: true)
class DEMedicalPlanDoctorInformation {

  /// Doctor fields
  List<DEMedicalPlanDoctorField> fields;

  DEMedicalPlanDoctorInformation(this.fields);

  factory DEMedicalPlanDoctorInformation.fromJson(Map<String, dynamic> json) =>
      _$DEMedicalPlanDoctorInformationFromJson(json);

  Map<String, dynamic> toJson() => _$DEMedicalPlanDoctorInformationToJson(this);
}

/// German medical plan doctor field
@JsonSerializable(
    nullable: true,
    createFactory: true,
    includeIfNull: false,
    explicitToJson: true)
class DEMedicalPlanDoctorField {

  /// Value
  String value;

  /// Type
  DEMedicalPlanDoctorFieldType type;

  DEMedicalPlanDoctorField(this.value, this.type);

  factory DEMedicalPlanDoctorField.fromJson(Map<String, dynamic> json) =>
      _$DEMedicalPlanDoctorFieldFromJson(json);

  Map<String, dynamic> toJson() => _$DEMedicalPlanDoctorFieldToJson(this);
}

/**
 * German medical plan document doctor information description field type
 */
enum DEMedicalPlanDoctorFieldType {
  IssuerName, // MP.A.n
  DoctorNumber, // MP.A.lanr
  PharmacyID, // MP.A.idf
  HospitalID, // MP.A.kik
  Street, // MP.A.s
  PostalCode, // MP.A.z
  Place, // MP.A.c
  TelephoneNumber, // MP.A.p
  Email, // MP.A.e
  IssuingDateAndTime, // MP.A.t
}

/// German medical plan standard subheading
@JsonSerializable(
    nullable: true,
    createFactory: true,
    includeIfNull: false,
    explicitToJson: true)
class DEMedicalPlanStandardSubheading {

  /// General notes
  List<String> generalNotes;

  /// Fields
  List<DEMedicalPlanStandardSubheadingField> fields;

  /// Medicines
  List<DEMedicalPlanMedicine> medicines;

  /// Receipes
  List<DEMedicalPlanSubheadingPrescription> prescriptions;


  DEMedicalPlanStandardSubheading(this.generalNotes, this.fields,
      this.medicines, this.prescriptions);

  factory DEMedicalPlanStandardSubheading.fromJson(Map<String, dynamic> json) =>
      _$DEMedicalPlanStandardSubheadingFromJson(json);

  Map<String, dynamic> toJson() =>
      _$DEMedicalPlanStandardSubheadingToJson(this);
}

/// German medical plan standard subheading field
@JsonSerializable(
    nullable: true,
    createFactory: true,
    includeIfNull: false,
    explicitToJson: true)
class DEMedicalPlanStandardSubheadingField {

  /// Value
  String value;

  /// Type
  DEMedicalPlanStandardSubheadingFieldType type;

  DEMedicalPlanStandardSubheadingField(this.value, this.type);

  factory DEMedicalPlanStandardSubheadingField.fromJson(
      Map<String, dynamic> json) =>
      _$DEMedicalPlanStandardSubheadingFieldFromJson(json);

  Map<String, dynamic> toJson() =>
      _$DEMedicalPlanStandardSubheadingFieldToJson(this);
}

/// German medical plan document subheading information description field type
enum DEMedicalPlanStandardSubheadingFieldType {
  KeyWords, // MP.S.c
  SubheadingFreeText, // MP.S.t
}

/// German medical plan medicine
@JsonSerializable(
    nullable: true,
    createFactory: true,
    includeIfNull: false,
    explicitToJson: true)
class DEMedicalPlanMedicine {

  /// Fields
  List<DEMedicalPlanMedicineField> fields;

  /// Substances
  List<DEMedicalPlanMedicineSubstance> substances;


  DEMedicalPlanMedicine(this.fields, this.substances);

  factory DEMedicalPlanMedicine.fromJson(Map<String, dynamic> json) =>
      _$DEMedicalPlanMedicineFromJson(json);

  Map<String, dynamic> toJson() => _$DEMedicalPlanMedicineToJson(this);
}

/// German medical plan medicine field
@JsonSerializable(
    nullable: true,
    createFactory: true,
    includeIfNull: false,
    explicitToJson: true)
class DEMedicalPlanMedicineField {

  /// Value
  String value;

  /// Type
  DEMedicalPlanMedicineFieldType type;

  DEMedicalPlanMedicineField(this.value, this.type);

  factory DEMedicalPlanMedicineField.fromJson(Map<String, dynamic> json) =>
      _$DEMedicalPlanMedicineFieldFromJson(json);

  Map<String, dynamic> toJson() => _$DEMedicalPlanMedicineFieldToJson(this);
}

/// German medical plan document medicine information description field type
enum DEMedicalPlanMedicineFieldType {
  PharmaceuticalNumber, // MP.S.M.p
  DrugName, // MP.S.M.a
  DosageForm, // MP.S.M.f
  DosageFormFreeText, // MP.S.M.fd
  Morning, // MP.S.M.m
  Midday, // MP.S.M.d
  Evening, // MP.S.M.v
  Night, // MP.S.M.h
  DosageFreeText, // MP.S.M.t
  DosingUnit, // MP.S.M.du
  DosingUnitFreeText, // MP.S.M.dud
  RelevantInfo, // MP.S.M.i
  ReasonForTreatment, // MP.S.M.r
  GeneralNotes, // MP.S.M.x
}

/// German medical plan medicine substance
@JsonSerializable(
    nullable: true,
    createFactory: true,
    includeIfNull: false,
    explicitToJson: true)
class DEMedicalPlanMedicineSubstance {

  /// Fields
  List<DEMedicalPlanMedicineSubstanceField> fields;


  DEMedicalPlanMedicineSubstance(this.fields);

  factory DEMedicalPlanMedicineSubstance.fromJson(Map<String, dynamic> json) =>
      _$DEMedicalPlanMedicineSubstanceFromJson(json);

  Map<String, dynamic> toJson() => _$DEMedicalPlanMedicineSubstanceToJson(this);
}

/// German medical plan medicine substance field */
@JsonSerializable(
    nullable: true,
    createFactory: true,
    includeIfNull: false,
    explicitToJson: true)
class DEMedicalPlanMedicineSubstanceField {

  /// Value
  String value;

  /// Type
  DEMedicalPlanMedicineSubstanceFieldType type;

  DEMedicalPlanMedicineSubstanceField(this.value, this.type);

  factory DEMedicalPlanMedicineSubstanceField.fromJson(
      Map<String, dynamic> json) =>
      _$DEMedicalPlanMedicineSubstanceFieldFromJson(json);

  Map<String, dynamic> toJson() =>
      _$DEMedicalPlanMedicineSubstanceFieldToJson(this);
}

/// German medical plan document medicine substance information description field type
enum DEMedicalPlanMedicineSubstanceFieldType {
  ActiveSubstance, // MP.S.M.W.w
  Potency // MP.S.M.W.s
}

/// German medical plan subheading prescriptions
@JsonSerializable(
    nullable: true,
    createFactory: true,
    includeIfNull: false,
    explicitToJson: true)
class DEMedicalPlanSubheadingPrescription {

  /// Fields
  List<DEMedicalPlanSubheadingPrescriptionField> fields;

  DEMedicalPlanSubheadingPrescription(this.fields);

  factory DEMedicalPlanSubheadingPrescription.fromJson(
      Map<String, dynamic> json) =>
      _$DEMedicalPlanSubheadingPrescriptionFromJson(json);

  Map<String, dynamic> toJson() =>
      _$DEMedicalPlanSubheadingPrescriptionToJson(this);
}

/// German medical plan subheading prescriptions field
@JsonSerializable(
    nullable: true,
    createFactory: true,
    includeIfNull: false,
    explicitToJson: true)
class DEMedicalPlanSubheadingPrescriptionField {

  /// Value
  String value;

  /// Type
  DEMedicalPlanSubheadingPrescriptionFieldType type;

  DEMedicalPlanSubheadingPrescriptionField(this.type);

  factory DEMedicalPlanSubheadingPrescriptionField.fromJson(
      Map<String, dynamic> json) =>
      _$DEMedicalPlanSubheadingPrescriptionFieldFromJson(json);

  Map<String, dynamic> toJson() =>
      _$DEMedicalPlanSubheadingPrescriptionFieldToJson(this);
}

/// German medical plan document subheading prescriptions information description field type
enum DEMedicalPlanSubheadingPrescriptionFieldType {
  GeneralInformation, // MP.S.R.x
  PrescriptionFreeText // MP.S.R.t
}

==> scanbot_sdk-2.9.0.tar.gz: lib/barcode_parsers/de_medical_plan.dart <==
import 'dart:core';

import 'package:json_annotation/json_annotation.dart';
import 'package:scanbot_sdk/barcode_parsers/barcode_scanner.dart';

part 'de_medical_plan.g.dart';

@JsonSerializable(
    createFactory: true, includeIfNull: false, explicitToJson: true)

/// German medical plan barcode parsed document
class DEMedicalPlanDocument extends BarcodeFormattedResult {
  static const String DOCUMENT_FORMAT = 'DEMedicalPlan';

  /// Document ID
  String GUID;

  /// Current page index
  int currentPage = 0;

  /// Total number of pages
  int totalNumberOfPages = 0;

  /// Document version
  String documentVersionNumber;

  /// Patch version
  String patchVersionNumber;

  /// Language and country code
  String languageCountryCode;

  /// Patient information
  DEMedicalPlanPatientInformation patient;

  /// Doctor information
  DEMedicalPlanDoctorInformation doctor;

  /// Treatment subheadings
  List<DEMedicalPlanStandardSubheading> subheadings;

  DEMedicalPlanDocument(
      this.GUID,
      this.currentPage,
      this.totalNumberOfPages,
      this.documentVersionNumber,
      this.patchVersionNumber,
      this.languageCountryCode,
      this.patient,
      this.doctor,
      this.subheadings)
      : super(DOCUMENT_FORMAT);

  factory DEMedicalPlanDocument.fromJson(Map<String, dynamic> json) =>
      _$DEMedicalPlanDocumentFromJson(json);

  @override
  Map<String, dynamic> toJson() => _$DEMedicalPlanDocumentToJson(this);
}

@JsonSerializable(
    createFactory: true, includeIfNull: false, explicitToJson: true)
class DEMedicalPlanPatientInformation {
  /// Patient fields
  List<DEMedicalPlanPatientField> fields;

  DEMedicalPlanPatientInformation(this.fields);

  factory DEMedicalPlanPatientInformation.fromJson(Map<String, dynamic> json) =>
      _$DEMedicalPlanPatientInformationFromJson(json);

  Map<String, dynamic> toJson() =>
      _$DEMedicalPlanPatientInformationToJson(this);
}

/// German medical plan patient information field
@JsonSerializable(
    createFactory: true, includeIfNull: false, explicitToJson: true)
class DEMedicalPlanPatientField {
  /// Value
  String value;

  /// Type
  DEMedicalPlanPatientFieldType type;

  DEMedicalPlanPatientField(this.value, this.type);

  factory DEMedicalPlanPatientField.fromJson(Map<String, dynamic> json) =>
      _$DEMedicalPlanPatientFieldFromJson(json);

  Map<String, dynamic> toJson() => _$DEMedicalPlanPatientFieldToJson(this);
}

/// German medical plan document patient information description field type
enum DEMedicalPlanPatientFieldType {
  FirstName, // MP.P.g
  LastName, // MP.P.f
  Title, // MP.P.t
  PreName, // MP.P.v
  Suffix, // MP.P.z
  PatientID, // MP.P.egk
  BirthDate, // MP.P.b
  Gender, // MP.P.s
  Weight, // MP.O.w
  Height, // MP.O.h
  CreatinineValue, // MP.O.c
  AllergiesAndIntolerances, // MP.O.ai
  BreastFeeding, // MP.O.b
  Pregnant, // MP.O.p
  PatientFreeText // MP.O.x
}

/// German medical plan doctor information
@JsonSerializable(
    createFactory: true, includeIfNull: false, explicitToJson: true)
class DEMedicalPlanDoctorInformation {
  /// Doctor fields
  List<DEMedicalPlanDoctorField> fields;

  DEMedicalPlanDoctorInformation(this.fields);

  factory DEMedicalPlanDoctorInformation.fromJson(Map<String, dynamic> json) =>
      _$DEMedicalPlanDoctorInformationFromJson(json);

  Map<String, dynamic> toJson() => _$DEMedicalPlanDoctorInformationToJson(this);
}

/// German medical plan doctor field
@JsonSerializable(
    createFactory: true, includeIfNull: false, explicitToJson: true)
class DEMedicalPlanDoctorField {
  /// Value
  String value;

  /// Type
  DEMedicalPlanDoctorFieldType type;

  DEMedicalPlanDoctorField(this.value, this.type);

  factory DEMedicalPlanDoctorField.fromJson(Map<String, dynamic> json) =>
      _$DEMedicalPlanDoctorFieldFromJson(json);

  Map<String, dynamic> toJson() => _$DEMedicalPlanDoctorFieldToJson(this);
}

///German medical plan document doctor information description field type

enum DEMedicalPlanDoctorFieldType {
  IssuerName, // MP.A.n
  DoctorNumber, // MP.A.lanr
  PharmacyID, // MP.A.idf
  HospitalID, // MP.A.kik
  Street, // MP.A.s
  PostalCode, // MP.A.z
  Place, // MP.A.c
  TelephoneNumber, // MP.A.p
  Email, // MP.A.e
  IssuingDateAndTime, // MP.A.t
}

/// German medical plan standard subheading
@JsonSerializable(
    createFactory: true, includeIfNull: false, explicitToJson: true)
class DEMedicalPlanStandardSubheading {
  /// General notes
  List<String> generalNotes;

  /// Fields
  List<DEMedicalPlanStandardSubheadingField> fields;

  /// Medicines
  List<DEMedicalPlanMedicine> medicines;

  /// Receipes
  List<DEMedicalPlanSubheadingPrescription> prescriptions;

  DEMedicalPlanStandardSubheading(
      this.generalNotes, this.fields, this.medicines, this.prescriptions);

  factory DEMedicalPlanStandardSubheading.fromJson(Map<String, dynamic> json) =>
      _$DEMedicalPlanStandardSubheadingFromJson(json);

  Map<String, dynamic> toJson() =>
      _$DEMedicalPlanStandardSubheadingToJson(this);
}

/// German medical plan standard subheading field
@JsonSerializable(
    createFactory: true, includeIfNull: false, explicitToJson: true)
class DEMedicalPlanStandardSubheadingField {
  /// Value
  String value;

  /// Type
  DEMedicalPlanStandardSubheadingFieldType type;

  DEMedicalPlanStandardSubheadingField(this.value, this.type);

  factory DEMedicalPlanStandardSubheadingField.fromJson(
          Map<String, dynamic> json) =>
      _$DEMedicalPlanStandardSubheadingFieldFromJson(json);

  Map<String, dynamic> toJson() =>
      _$DEMedicalPlanStandardSubheadingFieldToJson(this);
}

/// German medical plan document subheading information description field type
enum DEMedicalPlanStandardSubheadingFieldType {
  KeyWords, // MP.S.c
  SubheadingFreeText, // MP.S.t
}

/// German medical plan medicine
@JsonSerializable(
    createFactory: true, includeIfNull: false, explicitToJson: true)
class DEMedicalPlanMedicine {
  /// Fields
  List<DEMedicalPlanMedicineField> fields;

  /// Substances
  List<DEMedicalPlanMedicineSubstance> substances;

  DEMedicalPlanMedicine(this.fields, this.substances);

  factory DEMedicalPlanMedicine.fromJson(Map<String, dynamic> json) =>
      _$DEMedicalPlanMedicineFromJson(json);

  Map<String, dynamic> toJson() => _$DEMedicalPlanMedicineToJson(this);
}

/// German medical plan medicine field
@JsonSerializable(
    createFactory: true, includeIfNull: false, explicitToJson: true)
class DEMedicalPlanMedicineField {
  /// Value
  String value;

  /// Type
  DEMedicalPlanMedicineFieldType type;

  DEMedicalPlanMedicineField(this.value, this.type);

  factory DEMedicalPlanMedicineField.fromJson(Map<String, dynamic> json) =>
      _$DEMedicalPlanMedicineFieldFromJson(json);

  Map<String, dynamic> toJson() => _$DEMedicalPlanMedicineFieldToJson(this);
}

/// German medical plan document medicine information description field type
enum DEMedicalPlanMedicineFieldType {
  PharmaceuticalNumber, // MP.S.M.p
  DrugName, // MP.S.M.a
  DosageForm, // MP.S.M.f
  DosageFormFreeText, // MP.S.M.fd
  Morning, // MP.S.M.m
  Midday, // MP.S.M.d
  Evening, // MP.S.M.v
  Night, // MP.S.M.h
  DosageFreeText, // MP.S.M.t
  DosingUnit, // MP.S.M.du
  DosingUnitFreeText, // MP.S.M.dud
  RelevantInfo, // MP.S.M.i
  ReasonForTreatment, // MP.S.M.r
  GeneralNotes, // MP.S.M.x
}

/// German medical plan medicine substance
@JsonSerializable(
    createFactory: true, includeIfNull: false, explicitToJson: true)
class DEMedicalPlanMedicineSubstance {
  /// Fields
  List<DEMedicalPlanMedicineSubstanceField> fields;

  DEMedicalPlanMedicineSubstance(this.fields);

  factory DEMedicalPlanMedicineSubstance.fromJson(Map<String, dynamic> json) =>
      _$DEMedicalPlanMedicineSubstanceFromJson(json);

  Map<String, dynamic> toJson() => _$DEMedicalPlanMedicineSubstanceToJson(this);
}

/// German medical plan medicine substance field
@JsonSerializable(
    createFactory: true, includeIfNull: false, explicitToJson: true)
class DEMedicalPlanMedicineSubstanceField {
  /// Value
  String value;

  /// Type
  DEMedicalPlanMedicineSubstanceFieldType type;

  DEMedicalPlanMedicineSubstanceField(this.value, this.type);

  factory DEMedicalPlanMedicineSubstanceField.fromJson(
          Map<String, dynamic> json) =>
      _$DEMedicalPlanMedicineSubstanceFieldFromJson(json);

  Map<String, dynamic> toJson() =>
      _$DEMedicalPlanMedicineSubstanceFieldToJson(this);
}

/// German medical plan document medicine substance information description field type
enum DEMedicalPlanMedicineSubstanceFieldType {
  ActiveSubstance, // MP.S.M.W.w
  Potency // MP.S.M.W.s
}

/// German medical plan subheading prescriptions
@JsonSerializable(
    createFactory: true, includeIfNull: false, explicitToJson: true)
class DEMedicalPlanSubheadingPrescription {
  /// Fields
  List<DEMedicalPlanSubheadingPrescriptionField> fields;

  DEMedicalPlanSubheadingPrescription(this.fields);

  factory DEMedicalPlanSubheadingPrescription.fromJson(
          Map<String, dynamic> json) =>
      _$DEMedicalPlanSubheadingPrescriptionFromJson(json);

  Map<String, dynamic> toJson() =>
      _$DEMedicalPlanSubheadingPrescriptionToJson(this);
}

/// German medical plan subheading prescriptions field
@JsonSerializable(
    createFactory: true, includeIfNull: false, explicitToJson: true)
class DEMedicalPlanSubheadingPrescriptionField {
  /// Value
  String value;

  /// Type
  DEMedicalPlanSubheadingPrescriptionFieldType type;

  DEMedicalPlanSubheadingPrescriptionField(this.value, this.type);

  factory DEMedicalPlanSubheadingPrescriptionField.fromJson(
          Map<String, dynamic> json) =>
      _$DEMedicalPlanSubheadingPrescriptionFieldFromJson(json);

  Map<String, dynamic> toJson() =>
      _$DEMedicalPlanSubheadingPrescriptionFieldToJson(this);
}

/// German medical plan document subheading prescriptions information description field type
enum DEMedicalPlanSubheadingPrescriptionFieldType {
  GeneralInformation, // MP.S.R.x
  PrescriptionFreeText // MP.S.R.t
}
